@@ -14,7 +14,9 @@ from math import sqrt
 import torch
 from torch.nn import Dropout, Module
 
-from ..attention_registry import AttentionRegistry, Optional, Float
+from ..attention_registry import AttentionRegistry, Optional, Float, \
+    EventDispatcherInstance
+from ..events import EventDispatcher, AttentionEvent
 
 
 class FullAttention(Module):
@@ -27,11 +29,16 @@ class FullAttention(Module):
                       runtime)
         attention_dropout: The dropout rate to apply to the attention
                            (default: 0.1)
+        event_dispatcher: str or EventDispatcher instance to be used by this
+                          module for dispatching events (default: the default
+                          global dispatcher)
     """
-    def __init__(self, softmax_temp=None, attention_dropout=0.1):
+    def __init__(self, softmax_temp=None, attention_dropout=0.1,
+                 event_dispatcher=""):
         super(FullAttention, self).__init__()
         self.softmax_temp = softmax_temp
         self.dropout = Dropout(attention_dropout)
+        self.event_dispatcher = EventDispatcher.get(event_dispatcher)
 
     def forward(self, queries, keys, values, attn_mask, query_lengths,
                 key_lengths):
@@ -54,16 +61,24 @@ class FullAttention(Module):
         _, S, _, D = values.shape
         softmax_temp = self.softmax_temp or 1./sqrt(E)
 
+        # Scale the queries instead of applying the softmax temperature to the
+        # dot products
+        queries = queries * softmax_temp
+
         # Compute the unnormalized attention and apply the masks
         QK = torch.einsum("nlhe,nshe->nhls", queries, keys)
         if not attn_mask.all_ones:
             QK = QK + attn_mask.additive_matrix
-        QK = QK + key_lengths.additive_matrix[:, None, None]
+        if not key_lengths.all_ones:
+            QK = QK + key_lengths.additive_matrix[:, None, None]
 
         # Compute the attention and the weighted average
-        A = self.dropout(torch.softmax(softmax_temp * QK, dim=-1))
+        A = self.dropout(torch.softmax(QK, dim=-1))
         V = torch.einsum("nhls,nshd->nlhd", A, values)
 
+        # Let the world know of the attention matrix
+        self.event_dispatcher.dispatch(AttentionEvent(self, A))
+
         # Make sure that what we return is contiguous
         return V.contiguous()
 
@@ -74,6 +89,7 @@ AttentionRegistry.register(
     "full", FullAttention,
     [
         ("softmax_temp", Optional(Float)),
-        ("attention_dropout", Optional(Float, 0.1))
+        ("attention_dropout", Optional(Float, 0.1)),
+        ("event_dispatcher", Optional(EventDispatcherInstance, ""))
     ]
 )
